ToOptionVecString

Trait ToOptionVecString 

pub trait ToOptionVecString {
    // Required method
    fn to_option_vec_string(self) -> Option<Vec<String>>;
}
You need to make sure this trait is imported by any code that wants to use the C!, DC!, or M! macros.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToOptionVecString for &str

Source

impl ToOptionVecString for String

Source

impl<T: ToOptionVecString + Clone> ToOptionVecString for &T

Source

impl<T: ToOptionVecString + Clone> ToOptionVecString for &[T]

Source

impl<T: ToOptionVecString> ToOptionVecString for Option<T>

Source

impl<T: ToOptionVecString> ToOptionVecString for Vec<T>

Implementors